"""
************************************************************
meta.py - implementation detail meta information
************************************************************

Project: HALCON/Python

Description:
Information that gets generated by the build system.
Separate file to avoid slow iteration test cycle on changes to 'main' sources.

************************************************************

(c) 1996-2020 by MVTec Software GmbH

Software by: MVTec Software GmbH, www.mvtec.com
"""

__all__ = [
    'expected_halcon_version',
    'halcon_native_lib_names',
    'hdevengine_native_lib_names',
    'use_halcon_xl',
]

halcon_native_lib_names = {
    'linux': {
        'base': 'libhalcon.so.{}',
        'version': '23.11.0',
        'fallback': 'libhalcon.so',
    },
    'darwin': {
        'base': 'HALCON.framework/Versions/{}/HALCON',
        'version': '23.11P',
    },
    'win': 'halcon.dll',
}

expected_halcon_version = '23.11.0'

hdevengine_native_lib_names = {
    'linux': 'libhdevenginecpp.so.23.11.0',
    'darwin': 'HDevEngineCpp.framework/Versions/'
    '23.11P/HDevEngineCpp',
    'win': 'hdevenginecpp.dll',
}


def use_halcon_xl():
    """Override dynamic library names for xl usage"""
    global halcon_native_lib_names
    halcon_native_lib_names['linux']['base'] = 'libhalconxl.so.{}'
    halcon_native_lib_names['linux']['fallback'] = 'libhalconxl.so'
    halcon_native_lib_names['win'] = 'halconxl.dll'

    global hdevengine_native_lib_names
    hdevengine_native_lib_names['linux'] = 'libhdevenginecppxl.so.23.11.0'
    hdevengine_native_lib_names['win'] = 'hdevenginecppxl.dll'
